@@ -26,6 +26,11 @@
 
 
 #include <config.h>
+
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-config.h>
+#include <libgnome/gnome-i18n.h>
+
 #include <math.h>
 #include <guppi-convenient.h>
 #include <gnan.h>
