@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-seq-boolean-core-impl.c,v 1.9 2000/12/17 05:24:52 trow Exp $ */
+/* $Id: guppi-seq-boolean-core-impl.c,v 1.10 2001/01/16 23:35:49 trow Exp $ */
 
 /*
  * guppi-seq-boolean-core-impl.c
@@ -26,7 +26,11 @@
  */
 
 #include <config.h>
-#include <gnome.h>
+/* #include <gnome.h> */
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-config.h>
+#include <libgnome/gnome-i18n.h>
+
 #include <guppi-string.h>
 #include <guppi-convenient.h>
 #include <guppi-data-impl-plug-in.h>
@@ -797,4 +801,4 @@ guppi_plug_in (void)
 }
 
 
-/* $Id: guppi-seq-boolean-core-impl.c,v 1.9 2000/12/17 05:24:52 trow Exp $ */
+/* $Id: guppi-seq-boolean-core-impl.c,v 1.10 2001/01/16 23:35:49 trow Exp $ */
