@@ -1,4 +1,4 @@
-/* $Id: delim-import-widget.c,v 1.6 2000/12/14 20:22:54 trow Exp $ */
+/* $Id: delim-import-widget.c,v 1.7 2001/01/16 23:35:54 trow Exp $ */
 
 /*
  * delim-import-widget.c
@@ -25,6 +25,24 @@
  */
 
 #include <config.h>
+#include <stdlib.h>
+
+#include <gtk/gtktogglebutton.h>
+#include <gtk/gtkmenuitem.h>
+#include <gtk/gtktable.h>
+#include <gtk/gtkcheckbutton.h>
+#include <gtk/gtkcompat.h>
+#include <gtk/gtksignal.h>
+#include <gtk/gtkoptionmenu.h>
+#include <gtk/gtkscrolledwindow.h>
+#include <gtk/gtkspinbutton.h>
+#include <gtk/gtkentry.h>
+#include <gtk/gtkcombo.h>
+
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-config.h>
+#include <libgnome/gnome-i18n.h>
+
 #include <ctype.h>
 #include <glade/glade.h>
 #include <guppi-paths.h>
@@ -656,4 +674,4 @@ guppi_delimited_importer_widget (GuppiDelimitedImporter * gdi)
 }
 
 
-/* $Id: delim-import-widget.c,v 1.6 2000/12/14 20:22:54 trow Exp $ */
+/* $Id: delim-import-widget.c,v 1.7 2001/01/16 23:35:54 trow Exp $ */
