@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-delimited-importer.c,v 1.13 2000/12/16 03:42:45 trow Exp $ */
+/* $Id: guppi-delimited-importer.c,v 1.14 2001/01/16 23:35:54 trow Exp $ */
 
 /*
  * guppi-delimited-importer.c
@@ -26,6 +26,17 @@
  */
 
 #include <config.h>
+
+#include <stdlib.h>
+
+#include <gtk/gtksignal.h>
+#include <gtk/gtkmain.h>
+
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-config.h>
+#include <libgnome/gnome-i18n.h>
+#include <libgnome/gnome-util.h>
+
 #include <ctype.h>
 #include <guppi-convenient.h>
 #include <guppi-progress.h>
@@ -1175,4 +1186,4 @@ guppi_delimited_importer_import (GuppiDataImporter * imp,
 
 
 
-/* $Id: guppi-delimited-importer.c,v 1.13 2000/12/16 03:42:45 trow Exp $ */
+/* $Id: guppi-delimited-importer.c,v 1.14 2001/01/16 23:35:54 trow Exp $ */
