@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-axis-state.c,v 1.18 2000/12/19 00:35:55 trow Exp $ */
+/* $Id: guppi-axis-state.c,v 1.19 2001/01/16 23:35:56 trow Exp $ */
 
 /*
  * guppi-axis-state.c
@@ -26,6 +26,11 @@
  */
 
 #include <config.h>
+
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-config.h>
+#include <libgnome/gnome-i18n.h>
+
 #include <math.h>
 #include <guppi-useful.h>
 #include <guppi-shared-hash.h>
@@ -1294,4 +1299,4 @@ guppi_axis_state_label_shrink_to_fit_factor (GuppiAxisState * state,
   return min_factor;
 }
 
-/* $Id: guppi-axis-state.c,v 1.18 2000/12/19 00:35:55 trow Exp $ */
+/* $Id: guppi-axis-state.c,v 1.19 2001/01/16 23:35:56 trow Exp $ */
