@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-barchart-state.c,v 1.18 2000/12/14 20:22:56 trow Exp $ */
+/* $Id: guppi-barchart-state.c,v 1.19 2001/01/16 23:35:59 trow Exp $ */
 
 /*
  * guppi-barchart-state.c
@@ -26,6 +26,11 @@
  */
 
 #include <config.h>
+
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-config.h>
+#include <libgnome/gnome-i18n.h>
+
 #include <guppi-rgb.h>
 #include <guppi-seq-scalar.h>
 #include <guppi-seq-data.h>
@@ -905,4 +910,4 @@ guint32 guppi_barchart_state_col_color (GuppiBarchartState * state, gint c)
 }
 
 
-/* $Id: guppi-barchart-state.c,v 1.18 2000/12/14 20:22:56 trow Exp $ */
+/* $Id: guppi-barchart-state.c,v 1.19 2001/01/16 23:35:59 trow Exp $ */
