@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-boxplot-item.c,v 1.15 2000/12/03 00:25:42 trow Exp $ */
+/* $Id: guppi-boxplot-item.c,v 1.16 2001/01/16 23:36:00 trow Exp $ */
 
 /*
  * guppi-boxplot-item.c
@@ -26,6 +26,10 @@
  */
 
 #include <config.h>
+
+#include <libgnomeui/gnome-canvas.h>
+#include <libgnomeui/gnome-canvas-util.h>
+
 #include <unistd.h>
 #include <fcntl.h>
 #include <guppi-convenient.h>
@@ -450,4 +454,4 @@ GtkType guppi_boxplot_item_get_type (void)
   return guppi_boxplot_item_type;
 }
 
-/* $Id: guppi-boxplot-item.c,v 1.15 2000/12/03 00:25:42 trow Exp $ */
+/* $Id: guppi-boxplot-item.c,v 1.16 2001/01/16 23:36:00 trow Exp $ */
