@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-frame-state.c,v 1.7 2000/12/14 20:22:57 trow Exp $ */
+/* $Id: guppi-frame-state.c,v 1.8 2001/01/16 23:36:01 trow Exp $ */
 
 /*
  * guppi-frame-state.c
@@ -26,6 +26,11 @@
  */
 
 #include <config.h>
+
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-config.h>
+#include <libgnome/gnome-i18n.h>
+
 #include <guppi-useful.h>
 #include <guppi-rgb.h>
 #include "guppi-frame-state.h"
@@ -819,4 +824,4 @@ guppi_frame_state_set_frame_thickness (GuppiFrameState * state, double x)
 
 
 
-/* $Id: guppi-frame-state.c,v 1.7 2000/12/14 20:22:57 trow Exp $ */
+/* $Id: guppi-frame-state.c,v 1.8 2001/01/16 23:36:01 trow Exp $ */
