@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-pie-state.c,v 1.23 2000/12/14 20:22:58 trow Exp $ */
+/* $Id: guppi-pie-state.c,v 1.24 2001/01/16 23:36:03 trow Exp $ */
 
 /*
  * guppi-pie-state.c
@@ -26,6 +26,13 @@
  */
 
 #include <config.h>
+
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-config.h>
+#include <libgnome/gnome-i18n.h>
+
+#include <libgnomeui/gnome-color-picker.h>
+
 #include <math.h>
 #include <glade/glade.h>
 #include <guppi-useful.h>
@@ -1067,4 +1074,4 @@ guppi_pie_state_set_slice_offset (GuppiPieState * state, gint i, double x)
   guppi_element_state_changed (GUPPI_ELEMENT_STATE (state));
 }
 
-/* $Id: guppi-pie-state.c,v 1.23 2000/12/14 20:22:58 trow Exp $ */
+/* $Id: guppi-pie-state.c,v 1.24 2001/01/16 23:36:03 trow Exp $ */
