@@ -1,4 +1,4 @@
-/* $Id: guppi-scatter-state.c,v 1.21 2000/12/22 05:35:09 trow Exp $ */
+/* $Id: guppi-scatter-state.c,v 1.22 2001/01/16 23:36:04 trow Exp $ */
 
 /*
  * guppi-scatter-state.c
@@ -25,6 +25,11 @@
  */
 
 #include <config.h>
+
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-config.h>
+#include <libgnome/gnome-i18n.h>
+
 #include <math.h>
 #include <glade/glade.h>
 #include <gtk/gtkmarshal.h>
@@ -798,4 +803,4 @@ guppi_scatter_state_brush_circle (GuppiScatterState * ss,
 
 
 
-/* $Id: guppi-scatter-state.c,v 1.21 2000/12/22 05:35:09 trow Exp $ */
+/* $Id: guppi-scatter-state.c,v 1.22 2001/01/16 23:36:04 trow Exp $ */
