@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-scatter-style.c,v 1.17 2000/12/14 20:22:59 trow Exp $ */
+/* $Id: guppi-scatter-style.c,v 1.18 2001/01/16 23:36:04 trow Exp $ */
 
 /*
  * guppi-scatter-style.c
@@ -26,6 +26,13 @@
  */
 
 #include <config.h>
+
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-config.h>
+#include <libgnome/gnome-i18n.h>
+
+#include <libgnomeui/gnome-color-picker.h>
+
 #include <glade/glade.h>
 #include <guppi-useful.h>
 #include "guppi-scatter-style.h"
@@ -971,4 +978,4 @@ guppi_scatter_style_calc_size2_gradient (GuppiScatterStyle * ss, double t)
   return a + t * (b - a);
 }
 
-/* $Id: guppi-scatter-style.c,v 1.17 2000/12/14 20:22:59 trow Exp $ */
+/* $Id: guppi-scatter-style.c,v 1.18 2001/01/16 23:36:04 trow Exp $ */
