@@ -1,4 +1,4 @@
-/* $Id: guppi-scatter-tools.c,v 1.12 2000/12/14 20:22:59 trow Exp $ */
+/* $Id: guppi-scatter-tools.c,v 1.13 2001/01/16 23:36:04 trow Exp $ */
 
 /*
  * guppi-scatter-tools.c
@@ -25,6 +25,11 @@
  */
 
 #include <config.h>
+
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-config.h>
+#include <libgnome/gnome-i18n.h>
+
 #include <guppi-useful.h>
 #include <guppi-basic-tools.h>
 #include "guppi-scatter-tools.h"
@@ -240,4 +245,4 @@ guppi_scatter_toolkit_brush (void)
 }
 
 
-/* $Id: guppi-scatter-tools.c,v 1.12 2000/12/14 20:22:59 trow Exp $ */
+/* $Id: guppi-scatter-tools.c,v 1.13 2001/01/16 23:36:04 trow Exp $ */
