@@ -1,10 +1,11 @@
 /* This is -*- C -*- */
-/* $Id: guppi-text-state.c,v 1.13 2000/12/14 20:23:01 trow Exp $ */
+/* $Id: guppi-text-state.c,v 1.17 2001/02/04 05:37:48 trow Exp $ */
 
 /*
  * guppi-text-state.c
  *
  * Copyright (C) 2000 EMC Capital Management, Inc.
+ * Copyright (C) 2001 Free Software Foundation, Inc.
  *
  * Developed by Jon Trowbridge <trow@gnu.org> and
  * Havoc Pennington <hp@pobox.com>.
@@ -26,6 +27,14 @@
  */
 
 #include <config.h>
+
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-config.h>
+#include <libgnome/gnome-i18n.h>
+
+#include <libgnomeui/gnome-color-picker.h>
+#include <libgnomeui/gnome-font-picker.h>
+
 #include <glade/glade.h>
 #include <guppi-convenient.h>
 #include <guppi-useful.h>
@@ -58,7 +67,7 @@ guppi_text_state_get_arg (GtkObject * obj, GtkArg * arg, guint arg_id)
   switch (arg_id) {
 
   case ARG_TEXT:
-    GTK_VALUE_STRING (*arg) = guppi_text_state_text (state);
+    GTK_VALUE_STRING (*arg) = (gchar *) guppi_text_state_text (state);
     break;
 
   case ARG_COLOR:
@@ -182,8 +191,7 @@ guppi_text_state_finalize (GtkObject * obj)
 {
   GuppiTextState *state = GUPPI_TEXT_STATE (obj);
 
-  guppi_free0 (state->text);
-  guppi_unref0 (state->font);
+  guppi_unref0 (state->block);
 
   if (parent_class->finalize)
     parent_class->finalize (obj);
@@ -412,7 +420,8 @@ init_xml_object (GuppiElementState *ges, GuppiAttributesXML *ax)
   GuppiTextState *state = GUPPI_TEXT_STATE (ges);
 
   if (guppi_attributes_xml_defined (ax, "text"))
-    state->text = guppi_strdup (guppi_attributes_xml_get_string (ax, "text"));
+    guppi_text_state_set_text (state,
+			       guppi_attributes_xml_get_string (ax, "text"));
 
   if (guppi_attributes_xml_defined (ax, "color"))
     state->text_color = guppi_attributes_xml_get_uint32 (ax, "color");
@@ -485,14 +494,17 @@ guppi_text_state_class_init (GuppiTextStateClass * klass)
 static void
 guppi_text_state_init (GuppiTextState * obj)
 {
-  /* Some silly defaults */
-  obj->text = guppi_strdup ("");
+  obj->block = guppi_text_block_new ();
+  gtk_signal_connect_object (GTK_OBJECT (obj->block),
+			     "changed",
+			     GTK_SIGNAL_FUNC (guppi_element_state_changed_delayed),
+			     GTK_OBJECT (obj));
+
+  /* Some silly defaults */  
+
   obj->text_color = 0x000000ff;
   obj->rot_angle = 0;
 
-  obj->font = guppi_default_font ();
-  guppi_ref (obj->font);
-
   obj->filled_text = TRUE;
   obj->outline_width = 0.5;
 
@@ -532,11 +544,7 @@ guppi_text_state_set_text (GuppiTextState * state, const gchar * text)
   g_return_if_fail (state != NULL);
   g_return_if_fail (text != NULL);
 
-  if (strcmp (state->text, text)) {
-    guppi_free (state->text);
-    state->text = guppi_strdup (text);
-    guppi_element_state_changed_delayed (GUPPI_ELEMENT_STATE (state));
-  }
+  guppi_text_block_set_text (state->block, text);
 }
 
 void
@@ -557,6 +565,7 @@ guppi_text_state_set_rot_angle (GuppiTextState * state, double theta)
 
   if (state->rot_angle != theta) {
     state->rot_angle = theta;
+    guppi_text_block_set_angle (state->block, theta);
     guppi_element_state_changed_delayed (GUPPI_ELEMENT_STATE (state));
   }
 }
@@ -567,21 +576,20 @@ guppi_text_state_set_font (GuppiTextState * state, GnomeFont * font)
   g_return_if_fail (state != NULL);
   g_return_if_fail (font != NULL);
 
-  if (state->font != font) {
-    guppi_refcounting_assign (state->font, font);
-    guppi_element_state_changed_delayed (GUPPI_ELEMENT_STATE (state));
-  }
+  guppi_text_block_set_font (state->block, font);
 }
 
 void
 guppi_text_state_set_font_size (GuppiTextState * state, double sz)
 {
+  GnomeFont *old_font;
+
   g_return_if_fail (state != NULL);
   g_return_if_fail (sz >= 0);
 
-  if (state->font && gnome_font_get_size (state->font) != sz) {
-    GnomeFont *new_font;
-    new_font = gnome_font_new (gnome_font_get_name (state->font), sz);
+  old_font = guppi_text_block_font (state->block);
+  if (gnome_font_get_size (old_font) != sz) {
+    GnomeFont *new_font = gnome_font_new (gnome_font_get_name (old_font), sz);
     guppi_text_state_set_font (state, new_font);
     guppi_unref (new_font);
   }
@@ -666,4 +674,4 @@ guppi_text_state_set_right_margin (GuppiTextState * state, double m)
 }
 
 
-/* $Id: guppi-text-state.c,v 1.13 2000/12/14 20:23:01 trow Exp $ */
+/* $Id: guppi-text-state.c,v 1.17 2001/02/04 05:37:48 trow Exp $ */
