@@ -1,4 +1,4 @@
-/* $Id: app_scm.c,v 1.4 2000/10/20 01:21:37 trow Exp $ */
+/* $Id: app_scm.c,v 1.5 2001/01/16 23:36:09 trow Exp $ */
 
 /*
  * app_scm.c
@@ -25,7 +25,7 @@
  */
 
 #include <config.h>
-#include <gnome.h>
+/* #include <gnome.h> */
 #include <guppi-useful.h>
 #include <guppi-guile.h>
 #include "term.h"
@@ -139,4 +139,4 @@ guppi_app_scm_init (void)
 
 
 
-/* $Id: app_scm.c,v 1.4 2000/10/20 01:21:37 trow Exp $ */
+/* $Id: app_scm.c,v 1.5 2001/01/16 23:36:09 trow Exp $ */
