@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-app.c,v 1.22 2000/12/19 04:53:45 trow Exp $ */
+/* $Id: guppi-app.c,v 1.23 2001/01/16 23:36:10 trow Exp $ */
 
 /*
  * guppi-app.c
@@ -26,6 +26,23 @@
  */
 
 #include <config.h>
+
+#include <string.h>
+
+#include <gtk/gtkscrolledwindow.h>
+
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-config.h>
+#include <libgnome/gnome-i18n.h>
+#include <libgnome/gnome-util.h>
+
+#include <libgnomeui/gnome-app.h>
+#include <libgnomeui/gnome-app-helper.h>
+#include <libgnomeui/gnome-appbar.h>
+#include <libgnomeui/gnome-types.h>
+#include <libgnomeui/gnome-dialog.h>
+#include <libgnomeui/gnome-stock.h>
+
 #include <guppi-useful.h>
 #include <guppi-data-tree-view.h>
 #include "about.h"
@@ -699,4 +716,4 @@ guppi_app_add_recently_visited_file (GuppiApp * app, const gchar * filename)
 
 
 
-/* $Id: guppi-app.c,v 1.22 2000/12/19 04:53:45 trow Exp $ */
+/* $Id: guppi-app.c,v 1.23 2001/01/16 23:36:10 trow Exp $ */
