@@ -1,4 +1,4 @@
-/* $Id: guppi.c,v 1.52 2000/12/19 23:57:20 trow Exp $ */
+/* $Id: guppi.c,v 1.53 2001/01/16 23:36:10 trow Exp $ */
 /*
  * guppi.c
  *
@@ -24,7 +24,7 @@
  */
 
 #include <config.h>
-#include <gnome.h>
+/* #include <gnome.h> */
 #include <glade/glade.h>
 #include <signal.h>
 #include <time.h>
@@ -422,4 +422,4 @@ main (int argc, char *argv[])
 }
 
 
-/* $Id: guppi.c,v 1.52 2000/12/19 23:57:20 trow Exp $ */
+/* $Id: guppi.c,v 1.53 2001/01/16 23:36:10 trow Exp $ */
