@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-data.c,v 1.29 2000/12/18 06:00:06 trow Exp $ */
+/* $Id: guppi-data.c,v 1.30 2001/01/16 23:36:12 trow Exp $ */
 
 /*
  * guppi-data.c
@@ -26,8 +26,26 @@
  */
 
 #include <config.h>
+
+#include <string.h>
+
 #include <zlib.h>
-#include <gnome.h>
+/* #include <gnome.h> */
+#include <gtk/gtksignal.h>
+#include <gtk/gtkentry.h>
+#include <gtk/gtkwindow.h>
+#include <gtk/gtkvbox.h>
+#include <gtk/gtkhseparator.h>
+#include <gtk/gtkvseparator.h>
+#include <gtk/gtkfilesel.h>
+#include <gtk/gtkmenuitem.h>
+
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-config.h>
+#include <libgnome/gnome-i18n.h>
+#include <libgnomeui/gnome-dialog.h>
+#include <libgnomeui/gnome-stock.h>
+
 #include <guppi-useful.h>
 #include <guppi-dialogs.h>
 #include "guppi-data-impl-plug-in.h"
@@ -1352,5 +1370,5 @@ guppi_data_info_display (GuppiData *data)
   return frame;
 }
 
-/* $Id: guppi-data.c,v 1.29 2000/12/18 06:00:06 trow Exp $ */
+/* $Id: guppi-data.c,v 1.30 2001/01/16 23:36:12 trow Exp $ */
 
