@@ -25,7 +25,13 @@
  */
 
 #include <config.h>
-#include <gnome.h>
+#include <stdio.h>
+#include <stdlib.h>
+
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-config.h>
+#include <libgnome/gnome-i18n.h>
+
 #include <guppi-convenient.h>
 #include "guppi-price-series.h"
 #include "guppi-price-series-impl.h"
