@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-seq-boolean.c,v 1.15 2000/12/14 20:23:04 trow Exp $ */
+/* $Id: guppi-seq-boolean.c,v 1.16 2001/01/16 23:36:14 trow Exp $ */
 
 /*
  * guppi-seq-boolean.c
@@ -26,7 +26,12 @@
  */
 
 #include <config.h>
-#include <gnome.h>
+/* #include <gnome.h> */
+
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-config.h>
+#include <libgnome/gnome-i18n.h>
+
 #include <guppi-memory.h>
 #include "guppi-seq-boolean.h"
 #include "guppi-seq-boolean-impl.h"
@@ -721,4 +726,4 @@ gsize guppi_seq_boolean_true_count (const GuppiSeqBoolean * seq)
   return count;
 }
 
-/* $Id: guppi-seq-boolean.c,v 1.15 2000/12/14 20:23:04 trow Exp $ */
+/* $Id: guppi-seq-boolean.c,v 1.16 2001/01/16 23:36:14 trow Exp $ */
