@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-seq-integer.c,v 1.10 2000/12/14 20:23:04 trow Exp $ */
+/* $Id: guppi-seq-integer.c,v 1.11 2001/01/16 23:36:19 trow Exp $ */
 
 /*
  * guppi-seq-integer.c
@@ -26,7 +26,13 @@
  */
 
 #include <config.h>
-#include <gnome.h>
+/* #include <gnome.h> */
+#include <stdlib.h>
+
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-config.h>
+#include <libgnome/gnome-i18n.h>
+
 #include <guppi-convenient.h>
 #include <guppi-string.h>
 #include "guppi-seq-integer.h"
@@ -542,4 +548,4 @@ gint guppi_seq_integer_frequency (const GuppiSeqInteger * gsi, gint k)
 
 
 
-/* $Id: guppi-seq-integer.c,v 1.10 2000/12/14 20:23:04 trow Exp $ */
+/* $Id: guppi-seq-integer.c,v 1.11 2001/01/16 23:36:19 trow Exp $ */
