@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-seq-scalar.c,v 1.26 2000/12/14 20:23:04 trow Exp $ */
+/* $Id: guppi-seq-scalar.c,v 1.27 2001/01/16 23:36:21 trow Exp $ */
 
 /*
  * guppi-seq-scalar.c
@@ -27,12 +27,22 @@
 
 #include <config.h>
 #include <math.h>
+#include <stdlib.h>
+
+#include <gtk/gtklabel.h>
+#include <gtk/gtksignal.h>
+#include <gtk/gtktable.h>
+
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-config.h>
+#include <libgnome/gnome-i18n.h>
+
 #include <guppi-convenient.h>
 #include <guppi-string.h>
 #include "guppi-seq-scalar.h"
 #include "guppi-seq-scalar-impl.h"
 #include "guppi-seq-boolean.h"
-#include <gnome.h>
+/* #include <gnome.h> */
 
 typedef struct _GuppiSeqScalarPrivate GuppiSeqScalarPrivate;
 struct _GuppiSeqScalarPrivate {
@@ -1392,4 +1402,4 @@ info_display (GuppiData *data)
   return GTK_WIDGET (table);
 }
 
-/* $Id: guppi-seq-scalar.c,v 1.26 2000/12/14 20:23:04 trow Exp $ */
+/* $Id: guppi-seq-scalar.c,v 1.27 2001/01/16 23:36:21 trow Exp $ */
