@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-seq-string-impl.h,v 1.7 2000/10/27 18:22:59 trow Exp $ */
+/* $Id: guppi-seq-string-impl.h,v 1.8 2001/01/16 23:36:22 trow Exp $ */
 
 /*
  * guppi-seq-string-impl.h
@@ -28,7 +28,7 @@
 #ifndef _INC_GUPPI_SEQ_STRING_IMPL_H
 #define _INC_GUPPI_SEQ_STRING_IMPL_H
 
-#include <gtk/gtk.h>
+/* #include <gtk/gtk.h> */
 
 #include "guppi-seq-string.h"
 #include "guppi-seq-impl.h"
@@ -74,4 +74,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_SEQ_STRING_IMPL_H */
 
-/* $Id: guppi-seq-string-impl.h,v 1.7 2000/10/27 18:22:59 trow Exp $ */
+/* $Id: guppi-seq-string-impl.h,v 1.8 2001/01/16 23:36:22 trow Exp $ */
