@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-seq.h,v 1.15 2000/10/28 19:06:47 trow Exp $ */
+/* $Id: guppi-seq.h,v 1.16 2001/01/16 23:36:22 trow Exp $ */
 
 /*
  * guppi-seq.h
@@ -28,7 +28,7 @@
 #ifndef _INC_GUPPI_SEQ_H
 #define _INC_GUPPI_SEQ_H
 
-#include <gtk/gtk.h>
+/* #include <gtk/gtk.h> */
 #include "guppi-data.h"
 
 #include <guppi-defs.h>
@@ -137,4 +137,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_SEQ_H */
 
-/* $Id: guppi-seq.h,v 1.15 2000/10/28 19:06:47 trow Exp $ */
+/* $Id: guppi-seq.h,v 1.16 2001/01/16 23:36:22 trow Exp $ */
