@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-data-tree-view.c,v 1.17 2000/12/17 05:24:56 trow Exp $ */
+/* $Id: guppi-data-tree-view.c,v 1.18 2001/01/16 23:36:24 trow Exp $ */
 
 /*
  * guppi-data-tree-view.c
@@ -26,6 +26,20 @@
  */
 
 #include <config.h>
+
+#include <gtk/gtkclist.h>
+#include <gtk/gtkctree.h>
+#include <gtk/gtksignal.h>
+#include <gtk/gtkmenuitem.h>
+#include <gtk/gtkhseparator.h>
+#include <gtk/gtkselection.h>
+#include <gtk/gtkdnd.h>
+#include <gtk/gtkwindow.h>
+
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-config.h>
+#include <libgnome/gnome-i18n.h>
+
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <guppi-paths.h>
 #include <guppi-convenient.h>
@@ -400,4 +414,4 @@ guppi_data_tree_view_popup (GuppiDataTree * tree)
 
 
 
-/* $Id: guppi-data-tree-view.c,v 1.17 2000/12/17 05:24:56 trow Exp $ */
+/* $Id: guppi-data-tree-view.c,v 1.18 2001/01/16 23:36:24 trow Exp $ */
