@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-equation.h,v 1.6 2000/10/27 18:23:00 trow Exp $ */
+/* $Id: guppi-equation.h,v 1.7 2001/01/16 23:36:24 trow Exp $ */
 
 /*
  * guppi-equation.h
@@ -28,8 +28,8 @@
 #ifndef _INC_GUPPI_EQUATION_H
 #define _INC_GUPPI_EQUATION_H
 
-#include <gtk/gtk.h>
-
+/* #include <gtk/gtk.h> */
+#include <glib.h>
 #include <guppi-defs.h>
 
 BEGIN_GUPPI_DECLS 
@@ -115,4 +115,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_EQUATION_H */
 
-/* $Id: guppi-equation.h,v 1.6 2000/10/27 18:23:00 trow Exp $ */
+/* $Id: guppi-equation.h,v 1.7 2001/01/16 23:36:24 trow Exp $ */
