@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-alpha-template.c,v 1.19 2000/12/17 05:24:57 trow Exp $ */
+/* $Id: guppi-alpha-template.c,v 1.20 2001/01/16 23:36:25 trow Exp $ */
 
 /*
  * guppi-alpha-template.c
@@ -27,6 +27,10 @@
 
 #include <config.h>
 #include <math.h>
+
+#include <libgnomeui/gnome-canvas.h>
+#include <libgnomeui/gnome-canvas-util.h>
+
 #include <guppi-convenient.h>
 #include <guppi-useful.h>
 #include "guppi-alpha-template.h"
@@ -1152,4 +1156,4 @@ guppi_alpha_template_text_general (GnomeFont * font, double scale,
 
 
 
-/* $Id: guppi-alpha-template.c,v 1.19 2000/12/17 05:24:57 trow Exp $ */
+/* $Id: guppi-alpha-template.c,v 1.20 2001/01/16 23:36:25 trow Exp $ */
