@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-canvas-item.c,v 1.31 2000/12/21 22:23:33 trow Exp $ */
+/* $Id: guppi-canvas-item.c,v 1.33 2001/02/04 05:37:54 trow Exp $ */
 
 /*
  * guppi-element-canvas-item.c
@@ -27,6 +27,10 @@
 
 #include <config.h>
 #include <math.h>
+
+#include <libgnomeui/gnome-canvas.h>
+#include <libgnomeui/gnome-canvas-util.h>
+
 #include <guppi-useful.h>
 #include <guppi-unique-id.h>
 #include "guppi-element-view.h"
@@ -157,7 +161,7 @@ realize (GnomeCanvasItem * gnoitem)
 }
 
 static void
-update (GnomeCanvasItem * item, double aff[6], ArtSVP * clip_path, gint flags)
+update (GnomeCanvasItem *item, double aff[6], ArtSVP *clip_path, gint flags)
 {
   GuppiCanvasItem *gec;
   GuppiCanvasItemClass *klass;
@@ -900,9 +904,10 @@ guppi_canvas_item_request_total_redraw (GuppiCanvasItem * item)
 }
 
 void
-guppi_canvas_item_request_update (GuppiCanvasItem * gec)
+guppi_canvas_item_request_update (GuppiCanvasItem *gec)
 {
   g_return_if_fail (gec != NULL);
+
   gnome_canvas_item_request_update (GNOME_CANVAS_ITEM (gec));
 }
 
@@ -1372,5 +1377,5 @@ guppi_canvas_item_class_set_item_class_toolkit (GuppiCanvasItemClass *klass,
 }
 
 
-/* $Id: guppi-canvas-item.c,v 1.31 2000/12/21 22:23:33 trow Exp $ */
+/* $Id: guppi-canvas-item.c,v 1.33 2001/02/04 05:37:54 trow Exp $ */
 
