@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-element-print.c,v 1.14 2000/12/14 20:23:06 trow Exp $ */
+/* $Id: guppi-element-print.c,v 1.15 2001/02/04 05:37:54 trow Exp $ */
 
 /*
  * guppi-element-print.c
@@ -211,16 +211,32 @@ guppi_element_print_print (GuppiElementPrint * ep)
 
   guppi_element_print_gsave (ep);
 
-  /*
-     guppi_element_print_setlinewidth(ep, 72/64.0);
-     guppi_element_print_newpath(ep);
-     guppi_element_print_moveto(ep, ep->pt_x0, ep->pt_y0);
-     guppi_element_print_lineto(ep, ep->pt_x1, ep->pt_y0);
-     guppi_element_print_lineto(ep, ep->pt_x1, ep->pt_y1);
-     guppi_element_print_lineto(ep, ep->pt_x0, ep->pt_y1);
-     guppi_element_print_closepath(ep);
-     guppi_element_print_stroke(ep);
-   */
+#if 0
+  {
+    /* A frame around our print region.  Useful for debugging placement. */
+    double mx = (ep->pt_x0 + ep->pt_x1)/2;
+    double my = (ep->pt_y0 + ep->pt_y1)/2;
+
+    guppi_element_print_setlinewidth(ep, 72/64.0);
+    guppi_element_print_newpath (ep);
+    guppi_element_print_moveto (ep, ep->pt_x0, ep->pt_y0);
+    guppi_element_print_lineto (ep, ep->pt_x1, ep->pt_y0);
+    guppi_element_print_lineto (ep, ep->pt_x1, ep->pt_y1);
+    guppi_element_print_lineto (ep, ep->pt_x0, ep->pt_y1);
+    guppi_element_print_closepath (ep);
+    guppi_element_print_stroke (ep);
+
+    guppi_element_print_setlinewidth (ep, 72/128.0);
+    guppi_element_print_newpath (ep);
+    guppi_element_print_moveto (ep, ep->pt_x0, my);
+    guppi_element_print_lineto (ep, ep->pt_x1, my);
+    guppi_element_print_stroke (ep);
+    guppi_element_print_newpath (ep);
+    guppi_element_print_moveto (ep, mx, ep->pt_y0);
+    guppi_element_print_lineto (ep, mx, ep->pt_y1);
+    guppi_element_print_stroke (ep);
+  }
+#endif
 
   /* Clip to our bounding box */
   guppi_element_print_newpath (ep);
@@ -692,4 +708,4 @@ guppi_element_print_bpath_vp (GuppiElementPrint * ep, ArtBpath * bpath,
   guppi_free (bpath_copy);
 }
 
-/* $Id: guppi-element-print.c,v 1.14 2000/12/14 20:23:06 trow Exp $ */
+/* $Id: guppi-element-print.c,v 1.15 2001/02/04 05:37:54 trow Exp $ */
