@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-group-view.c,v 1.8 2000/12/17 05:24:57 trow Exp $ */
+/* $Id: guppi-group-view.c,v 1.9 2001/02/04 05:37:54 trow Exp $ */
 
 /*
  * guppi-group-view.c
@@ -251,7 +251,8 @@ touch (GuppiGroupView * grp)
   priv (grp)->touched = TRUE;
 }
 
-gboolean guppi_group_view_has (GuppiGroupView * grp, GuppiElementView * view)
+gboolean 
+guppi_group_view_has (GuppiGroupView * grp, GuppiElementView * view)
 {
   g_return_val_if_fail (grp != NULL && GUPPI_IS_GROUP_VIEW (grp), FALSE);
   g_return_val_if_fail (view != NULL && GUPPI_IS_ELEMENT_VIEW (view), FALSE);
@@ -1233,4 +1234,4 @@ guppi_group_view_layout_same_y_center (GuppiGroupView * grp,
 }
 
 
-/* $Id: guppi-group-view.c,v 1.8 2000/12/17 05:24:57 trow Exp $ */
+/* $Id: guppi-group-view.c,v 1.9 2001/02/04 05:37:54 trow Exp $ */
