@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-plot-window.c,v 1.29 2000/12/17 05:24:57 trow Exp $ */
+/* $Id: guppi-plot-window.c,v 1.30 2001/01/16 23:36:32 trow Exp $ */
 
 /*
  * guppi-plot-window.c
@@ -26,7 +26,17 @@
  */
 
 #include <config.h>
-#include <gnome.h>
+/* #include <gnome.h> */
+#include <time.h>
+
+#include <libgnome/gnome-paper.h>
+
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-config.h>
+#include <libgnome/gnome-i18n.h>
+
+#include <libgnomeui/gnome-app.h>
+#include <libgnomeui/gnome-app-helper.h>
 
 #include <libgnomeprint/gnome-print.h>
 #include <libgnomeprint/gnome-print-dialog.h>
@@ -672,4 +682,4 @@ guppi_plot_window_new (GuppiRootGroupView *root_view)
 
 
 
-/* $Id: guppi-plot-window.c,v 1.29 2000/12/17 05:24:57 trow Exp $ */
+/* $Id: guppi-plot-window.c,v 1.30 2001/01/16 23:36:32 trow Exp $ */
