@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-style.c,v 1.15 2000/12/17 05:24:57 trow Exp $ */
+/* $Id: guppi-style.c,v 1.16 2001/01/16 23:36:36 trow Exp $ */
 
 /*
  * guppi-style.c
@@ -26,6 +26,16 @@
  */
 
 #include <config.h>
+
+#include <gtk/gtkframe.h>
+#include <gtk/gtklabel.h>
+
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-config.h>
+#include <libgnome/gnome-i18n.h>
+
+#include <libgnomeui/gnome-color-picker.h>
+
 #include <guppi-convenient.h>
 #include <guppi-metrics.h>
 #include <guppi-rgb.h>
@@ -843,4 +853,4 @@ guppi_style_edit_window (GuppiStyle * style)
   }
 }
 
-/* $Id: guppi-style.c,v 1.15 2000/12/17 05:24:57 trow Exp $ */
+/* $Id: guppi-style.c,v 1.16 2001/01/16 23:36:36 trow Exp $ */
