@@ -1,4 +1,4 @@
-/* $Id: guppi-stat-init.c,v 1.2 2000/03/05 23:42:29 trow Exp $ */
+/* $Id: guppi-stat-init.c,v 1.6 2000/10/20 01:21:49 trow Exp $ */
 
 /*
  * guppi-stat-init.c
@@ -24,14 +24,25 @@
  * USA
  */
 
+#include <config.h>
+#include <guppi-guile.h>
 #include "guppi-scm-stat.h"
 #include "guppi-stat-init.h"
 
+#ifdef HAVE_PYTHON
+#include "guppi-python-stat.h"
+#endif
+
 void
-guppi_stat_init(void)
+guppi_stat_init (void)
 {
-  guppi_scm_stat_init();
+  if (guppi_guile_is_active ())
+    guppi_scm_stat_init ();
+
+#ifdef HAVE_PYTHON
+  guppi_python_stat_init ();
+#endif
 }
 
 
-/* $Id: guppi-stat-init.c,v 1.2 2000/03/05 23:42:29 trow Exp $ */
+/* $Id: guppi-stat-init.c,v 1.6 2000/10/20 01:21:49 trow Exp $ */
