@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-object-barchart.c,v 1.12 2000/12/19 00:35:57 trow Exp $ */
+/* $Id: guppi-object-barchart.c,v 1.13 2001/02/26 20:53:27 trow Exp $ */
 
 /*
  * guppi-object-barchart.c
@@ -306,6 +306,185 @@ guppi_object_barchart_finalize (GtkObject * obj)
 
 /*****************************************************************************/
 
+static GuppiData *
+build_bar_data(GuppiObjectBarchart *obar) 
+{
+  GuppiSeqScalar *ss;
+  GuppiSeqData *sd;
+  gint i, j, k = 0;
+  /* Convert our data into the appropriate GuppiSeq-derived objects. */
+  
+  if (obar->data_cols == 1) {
+    ss = GUPPI_SEQ_SCALAR (guppi_seq_scalar_new ());
+    for (i = 0; i < obar->data_rows; ++i)
+      guppi_seq_scalar_append (ss, obar->data[i]);
+    return GUPPI_DATA (ss);
+  } 
+
+  sd = GUPPI_SEQ_DATA (guppi_seq_data_new ());
+  for (j = 0; j < obar->data_cols; ++j) {
+    ss = GUPPI_SEQ_SCALAR (guppi_seq_scalar_new ());
+    for (i = 0; i < obar->data_rows; ++i) {
+      guppi_seq_scalar_append (ss, obar->data[k]);
+      ++k;
+    }
+    guppi_seq_data_append (sd, GUPPI_DATA (ss));
+    guppi_unref (ss);
+  }
+  return GUPPI_DATA (sd);
+}
+
+static GuppiSeqString *
+build_bar_labels(GuppiObjectBarchart * obar, int count, gchar ** source_labels) 
+{
+  GuppiSeqString *labels;
+  gint i;
+
+  labels = GUPPI_SEQ_STRING (guppi_seq_string_new ());
+
+  for (i = 0; i < count; ++i)
+    guppi_seq_string_append (labels, source_labels[i]);
+
+  return labels;
+}
+
+static GuppiSeqStyle *
+build_bar_colors(GuppiObjectBarchart * obar) 
+{
+  GuppiSeqStyle *col_colors;
+  gint i;
+  col_colors = GUPPI_SEQ_STYLE (guppi_seq_style_new ());
+  for (i = 0; i < obar->data_cols; ++i) {
+    GuppiStyle *sty = guppi_style_new ();
+    guppi_style_set_color (sty, obar->col_colors[i]);
+    guppi_seq_style_append (col_colors, sty);
+    guppi_unref (sty);
+  }
+  return col_colors;
+}
+
+static void
+update (GuppiObject *obj) 
+{
+  GuppiObjectBarchart *obar;
+  GuppiElementState *barchart_state = NULL;
+  GuppiElementState *legend_state = NULL;
+  GuppiElementState *bottom_axis_state = NULL;
+  GuppiElementState *left_axis_state = NULL;
+  GuppiSeqString *row_labels = NULL;
+  GuppiSeqString *col_labels = NULL;
+  GuppiSeqStyle *col_colors = NULL;
+  GuppiData *data;
+  GnomeFont *font;
+  
+  
+  obar = GUPPI_OBJECT_BARCHART (obj);
+    	
+  if (obar->data == NULL) {
+    g_warning("No barchart data specified.\n");
+    return;
+  }
+  
+  
+  barchart_state = guppi_element_view_state (obar->barchart_view);
+  guppi_ref (barchart_state);
+  
+  /* FIXME: if there wasn't a legend in the construction of the
+     object, it won't be created upon an update.  In the future we may
+     want to support construction of the legend upon update, but for
+     now..
+  */
+
+
+  if (obar->legend_view) {
+    legend_state = guppi_element_view_state (obar->legend_view);
+    guppi_ref (legend_state);
+  }
+  
+  data = build_bar_data (obar);
+
+  if (obar->row_labels) {
+    row_labels = build_bar_labels (obar, obar->data_rows, obar->row_labels);
+  }
+
+  /* FIXME: check for construction of legends. */
+
+  if (obar->legend_view && obar->col_labels) {
+    col_labels = build_bar_labels (obar, obar->data_cols, obar->col_labels);
+  }
+
+  if (obar->col_colors) {
+    col_colors = build_bar_colors (obar);
+  }
+  
+
+  
+  gtk_object_set (GTK_OBJECT (barchart_state),
+		 "data", data,
+		 "row_labels", row_labels,
+		 "column_labels", col_labels,
+		 "column_styles", col_colors,
+		 NULL);
+  
+  guppi_element_state_changed (barchart_state);
+
+  font = obar->axis_font;
+  if (font == NULL)
+    font = guppi_default_font ();
+
+  bottom_axis_state = guppi_element_view_state (obar->bottom_axis_view);
+  guppi_ref (bottom_axis_state);
+
+  gtk_object_set (GTK_OBJECT (bottom_axis_state),
+		 "major_label_font", font,
+		 "rotate_labels", obar->rot_x_axis_labels,
+		 NULL);
+  guppi_element_state_changed (bottom_axis_state);
+  guppi_element_view_changed_size (obar->bottom_axis_view);
+
+  left_axis_state = guppi_element_view_state(obar->left_axis_view);
+  guppi_ref (left_axis_state);
+
+  gtk_object_set (GTK_OBJECT (left_axis_state),
+		 "major_label_font", font,
+		 "rotate_labels", obar->rot_y_axis_labels,
+		 NULL);
+  
+  guppi_element_state_changed (left_axis_state);
+  guppi_element_view_changed_size (obar->left_axis_view);
+
+  
+  if (col_labels != NULL) {
+
+    font = obar->legend_font;
+    if (font == NULL)
+      font = guppi_default_font ();
+
+
+    gtk_object_set (GTK_OBJECT (legend_state),
+		   "labels", col_labels,
+		   "styles", col_colors,
+		   "label_font", font,
+		   NULL);
+
+    guppi_element_state_changed (legend_state);
+    guppi_element_view_changed_size (obar->legend_view);   
+  }
+  
+ 
+  /* clean up */
+  
+  guppi_unref (barchart_state);
+  guppi_unref (legend_state);			   
+  guppi_unref (bottom_axis_state);
+  guppi_unref (left_axis_state);  
+  guppi_unref (data);
+  guppi_unref (row_labels);
+  guppi_unref (col_labels);
+  guppi_unref (col_colors);  
+}
+
+
 static GuppiElementView *
 build (GuppiObject * obj, double hsize, double vsize)
 {
@@ -345,56 +524,24 @@ build (GuppiObject * obj, double hsize, double vsize)
   guppi_unref0 (grp_state);
 
 
-  /* Convert our data into the appropriate GuppiSeq-derived objects. */
+  data = build_bar_data(obar);
 
-  if (obar->data_cols == 1) {
-    GuppiSeqScalar *ss = GUPPI_SEQ_SCALAR (guppi_seq_scalar_new ());
-    gint i;
-    for (i = 0; i < obar->data_rows; ++i)
-      guppi_seq_scalar_append (ss, obar->data[i]);
-    data = GUPPI_DATA (ss);
-  } else {
-    GuppiSeqData *sd = GUPPI_SEQ_DATA (guppi_seq_data_new ());
-    gint i, j, k = 0;
-    for (j = 0; j < obar->data_cols; ++j) {
-      GuppiSeqScalar *ss = GUPPI_SEQ_SCALAR (guppi_seq_scalar_new ());
-      for (i = 0; i < obar->data_rows; ++i) {
-	guppi_seq_scalar_append (ss, obar->data[k]);
-	++k;
-      }
-      guppi_seq_data_append (sd, GUPPI_DATA (ss));
-      guppi_unref (ss);
-    }
-    data = GUPPI_DATA (sd);
-  }
+ 
 
   /* Build up data objects for our labels. */
-
   if (obar->row_labels) {
-    gint i;
-    row_labels = GUPPI_SEQ_STRING (guppi_seq_string_new ());
-    for (i = 0; i < obar->data_rows; ++i)
-      guppi_seq_string_append (row_labels, obar->row_labels[i]);
+    row_labels = build_bar_labels (obar, obar->data_rows, obar->row_labels);
   }
 
   if (obar->col_labels) {
-    gint i;
-    col_labels = GUPPI_SEQ_STRING (guppi_seq_string_new ());
-    for (i = 0; i < obar->data_cols; ++i)
-      guppi_seq_string_append (col_labels, obar->col_labels[i]);
+    col_labels = build_bar_labels (obar, obar->data_cols, obar->col_labels);
   }
 
+
   /* Build up our color data */
 
   if (obar->col_colors) {
-    gint i;
-    col_colors = GUPPI_SEQ_STYLE (guppi_seq_style_new ());
-    for (i = 0; i < obar->data_cols; ++i) {
-      GuppiStyle *sty = guppi_style_new ();
-      guppi_style_set_color (sty, obar->col_colors[i]);
-      guppi_seq_style_append (col_colors, sty);
-      guppi_unref (sty);
-    }
+    col_colors = build_bar_colors (obar);
   }
 
   barchart_state = guppi_element_state_new ("barchart",
@@ -501,6 +648,8 @@ build (GuppiObject * obj, double hsize, double vsize)
 
   obar->legend_view = legend_view;
   obar->barchart_view = barchart_view;
+  obar->bottom_axis_view = bottom_axis_view;
+  obar->left_axis_view = left_axis_view;
 
 
   /* Clean up after ourselves... */
@@ -611,6 +760,7 @@ guppi_object_barchart_class_init (GuppiObjectBarchartClass * klass)
 
   gobj_class->build = build;
   gobj_class->item_init = item_init;
+  gobj_class->update = update;
 
   add_arg ("data_rows", GTK_TYPE_INT, ARG_DATA_ROWS);
   add_arg ("data_columns", GTK_TYPE_INT, ARG_DATA_COLUMNS);
@@ -691,4 +841,4 @@ guppi_object_barchart_new (void)
 
 
 
-/* $Id: guppi-object-barchart.c,v 1.12 2000/12/19 00:35:57 trow Exp $ */
+/* $Id: guppi-object-barchart.c,v 1.13 2001/02/26 20:53:27 trow Exp $ */
