@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-object-pie.c,v 1.15 2000/12/17 22:52:27 trow Exp $ */
+/* $Id: guppi-object-pie.c,v 1.16 2001/02/26 20:53:27 trow Exp $ */
 
 /*
  * guppi-object-pie.c
@@ -142,7 +142,7 @@ guppi_object_pie_set_arg (GtkObject * obj, GtkArg * arg, guint arg_id)
     if (opie->data_size <= 0)
       g_warning ("colors_rgb: Illegal data size: %d", opie->data_size);
     else {
-      guppi_free (opie->data);
+      guppi_free (opie->colors_rgb);
       opie->colors_rgb = guppi_new (guint32, opie->data_size);
       memcpy (opie->colors_rgb, GTK_VALUE_POINTER (*arg),
 	      opie->data_size * sizeof (guint32));
@@ -302,6 +302,141 @@ guppi_object_pie_finalize (GtkObject * obj)
 
 /*****************************************************************************/
 
+static GuppiSeqScalar *
+pie_build_data(GuppiObjectPie * opie) 
+{
+  GuppiSeqScalar *data;
+  int i;
+
+  data = GUPPI_SEQ_SCALAR (guppi_seq_scalar_new ());
+
+  for(i = 0; i < opie->data_size; i++) 
+    guppi_seq_scalar_append(data, opie->data[i]);
+
+  return data;  
+}
+
+static GuppiSeqString *
+pie_build_labels(GuppiObjectPie * opie) 
+{
+  GuppiSeqString *labels;
+  int i;
+
+  labels = GUPPI_SEQ_STRING (guppi_seq_string_new ());
+
+  for(i = 0; i < opie->data_size; i++) 
+    guppi_seq_string_append (labels, opie->labels[i]);
+
+  return labels;  
+}
+
+static GuppiSeqStyle *
+pie_build_colors(GuppiObjectPie * opie) 
+{
+  GuppiSeqStyle *colors;
+  GuppiStyle *sty;
+  guint32 c;
+  int i;
+
+  colors = GUPPI_SEQ_STYLE (guppi_seq_style_new ());
+
+  for(i = 0; i < opie->data_size; i++) {
+    sty = guppi_style_new ();
+    if(opie->colors_rgb) {
+      c = RGB_TO_RGBA (opie->colors_rgb[i], 0xff);    
+    } else {
+      c = guppi_str2color_rgba (opie->colors[i]);
+      if(!c)
+	g_message ("Unknown color: \"%s\"", opie->colors[i]);
+    }
+    guppi_style_set_color (sty, c);
+    guppi_seq_style_append (colors, sty);
+    guppi_unref0 (sty);
+  }
+  
+  return colors;
+}
+
+static void
+update (GuppiObject * obj) 
+{
+  GuppiGroupView *grp_view;
+  GuppiObjectPie *opie;
+  GuppiSeqScalar *pie_data;
+  GuppiSeqString *pie_labels = NULL;
+  GuppiSeqStyle *pie_colors = NULL;
+  GuppiElementState *legend_state = NULL;
+  GuppiElementState *pie_state = NULL;	
+  GnomeFont *font;
+  
+  g_return_if_fail (obj != NULL);
+  g_return_if_fail (GUPPI_IS_OBJECT_PIE (obj));
+  
+  opie = GUPPI_OBJECT_PIE (obj);
+  grp_view = GUPPI_GROUP_VIEW (guppi_object_view (obj));
+  
+  if (opie->data == NULL) {
+    g_warning("No pie data specified.");
+    return;
+  }
+  
+  pie_state = guppi_element_view_state(opie->pie_view);
+  guppi_ref (pie_state);
+  
+  /* FIXME: if the object now contains data for a lengend, but that
+     legend wasn't constructed in build(), we may need to construct it
+     here.  Right now it dosen't do that. */
+
+  if (opie->legend_view) {
+    legend_state = guppi_element_view_state (opie->legend_view);
+    guppi_ref (legend_state);
+  }
+
+  pie_data = pie_build_data(opie);
+
+  if (opie->labels) {
+    pie_labels = pie_build_labels(opie);
+  }
+  
+  if (opie->colors_rgb || opie->colors) {
+    pie_colors = pie_build_colors(opie);
+  }
+
+  gtk_object_set (GTK_OBJECT (pie_state),
+		  "data", pie_data,
+		  "radius_maximize", opie->radius_maximize,
+		  "radius_lock", opie->radius_lock,
+		  "radius", opie->radius_size,
+		  "data_labels", pie_labels,
+		  "data_styles", pie_colors,
+		  NULL);
+
+  guppi_element_state_changed(pie_state);
+  
+  if (legend_state) {
+    font = opie->legend_font;
+
+    if(font == NULL) 
+      font = guppi_default_font ();
+    
+    gtk_object_set (GTK_OBJECT (legend_state),
+		    "labels", pie_labels,
+		    "styles", pie_colors,
+		    "label_font", font,
+		    NULL);
+
+    guppi_element_state_changed (legend_state);
+    guppi_element_view_changed_size (opie->legend_view);
+
+  }
+
+  guppi_unref (legend_state);
+  guppi_unref (pie_state);
+  guppi_unref (pie_data);
+  guppi_unref (pie_labels);
+  guppi_unref (pie_colors);  
+}
+
 static GuppiElementView *
 build (GuppiObject * obj, double hsize, double vsize)
 {
@@ -321,7 +456,6 @@ build (GuppiObject * obj, double hsize, double vsize)
   GuppiElementView *legend_view = NULL;
   GuppiElementView *pie_view;
 
-  gint i;
 
   const double outer_margin = 3.6;
   const double inner_gap = 3.6;
@@ -342,35 +476,16 @@ build (GuppiObject * obj, double hsize, double vsize)
   guppi_unref0 (grp_state);
 
   /* Copy our data into a GuppiSeqScalar */
-  pie_data = GUPPI_SEQ_SCALAR (guppi_seq_scalar_new ());
-  for (i = 0; i < opie->data_size; ++i)
-    guppi_seq_scalar_append (pie_data, opie->data[i]);
+  pie_data = pie_build_data(opie);
 
-  if (opie->labels) {
-    pie_labels = GUPPI_SEQ_STRING (guppi_seq_string_new ());
-    for (i = 0; i < opie->data_size; ++i)
-      guppi_seq_string_append (pie_labels, opie->labels[i]);
-  }
 
-  if (opie->colors_rgb || opie->colors) {
+  if (opie->labels) 
+    pie_labels = pie_build_labels(opie);
+  
 
-    pie_colors = GUPPI_SEQ_STYLE (guppi_seq_style_new ());
-
-    for (i = 0; i < opie->data_size; ++i) {
-      GuppiStyle *sty = guppi_style_new ();
-      guint32 c;
-      if (opie->colors_rgb) {
-	c = RGB_TO_RGBA (opie->colors_rgb[i], 0xff);
-      } else {
-	c = guppi_str2color_rgba (opie->colors[i]);
-	if (c == 0)
-	  g_message ("Unknown color: \"%s\"", opie->colors[i]);
-      }
-      guppi_style_set_color (sty, c);
-      guppi_seq_style_append (pie_colors, sty);
-      guppi_unref0 (sty);
-    }
-  }
+  if (opie->colors_rgb || opie->colors)
+    pie_colors = pie_build_colors(opie);
+  
 
 
   /* We should take the font size into account here. */
@@ -524,6 +639,7 @@ guppi_object_pie_class_init (GuppiObjectPieClass * klass)
 
   gobj_class->build = build;
   gobj_class->item_init = item_init;
+  gobj_class->update = update;
 
   add_arg ("data_size", GTK_TYPE_INT, ARG_DATA_SIZE);
   add_arg ("data", GTK_TYPE_POINTER, ARG_DATA);
@@ -596,4 +712,4 @@ GtkType guppi_object_pie_get_type (void)
   return guppi_object_pie_type;
 }
 
-/* $Id: guppi-object-pie.c,v 1.15 2000/12/17 22:52:27 trow Exp $ */
+/* $Id: guppi-object-pie.c,v 1.16 2001/02/26 20:53:27 trow Exp $ */
