@@ -1,4 +1,4 @@
-/* $Id: guppi-debug.c,v 1.12 2000/12/01 01:34:30 trow Exp $ */
+/* $Id: guppi-debug.c,v 1.13 2001/01/16 23:36:40 trow Exp $ */
 
 /*
  * guppi-debug.c
@@ -25,7 +25,8 @@
  */
 
 #include <config.h>
-#include <gnome.h>
+/* #include <gnome.h> */
+#include <stdio.h>
 #include <sys/time.h>
 #include <unistd.h>
 #include <signal.h>
@@ -248,4 +249,4 @@ guppi_make_warnings_and_criticals_stop_in_debugger (const char *first_domain,
 }
 
 
-/* $Id: guppi-debug.c,v 1.12 2000/12/01 01:34:30 trow Exp $ */
+/* $Id: guppi-debug.c,v 1.13 2001/01/16 23:36:40 trow Exp $ */
