@@ -1,4 +1,4 @@
-/* $Id: guppi-debug.h,v 1.10 2000/10/27 18:23:05 trow Exp $ */
+/* $Id: guppi-debug.h,v 1.11 2001/01/16 23:36:40 trow Exp $ */
 
 /*
  * guppi-debug.h
@@ -27,9 +27,10 @@
 #ifndef _INC_GUPPI_DEBUG_H
 #define _INC_GUPPI_DEBUG_H
 
-#include <gtk/gtk.h>
+/* #include <gtk/gtk.h> */
 
 #include <guppi-defs.h>
+#include <glib.h>
 
 BEGIN_GUPPI_DECLS
 
@@ -153,4 +154,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_DEBUG_H */
 
-/* $Id: guppi-debug.h,v 1.10 2000/10/27 18:23:05 trow Exp $ */
+/* $Id: guppi-debug.h,v 1.11 2001/01/16 23:36:40 trow Exp $ */
