@@ -1,4 +1,4 @@
-/* $Id: guppi-dharma.c,v 1.5 2000/12/21 22:23:33 trow Exp $ */
+/* $Id: guppi-dharma.c,v 1.6 2001/01/16 23:36:40 trow Exp $ */
 
 /*
  * guppi-dharma.c
@@ -25,7 +25,8 @@
 
 #include <config.h>
 #include <string.h>
-#include <gtk/gtk.h>
+/* #include <gtk/gtk.h> */
+#include <gtk/gtkmain.h>
 #include "guppi-memory.h"
 #include "guppi-dharma.h"
 
@@ -121,4 +122,4 @@ guppi_dharma_init (void)
 }
 
 
-/* $Id: guppi-dharma.c,v 1.5 2000/12/21 22:23:33 trow Exp $ */
+/* $Id: guppi-dharma.c,v 1.6 2001/01/16 23:36:40 trow Exp $ */
