@@ -1,4 +1,4 @@
-/* $Id: guppi-enums.h,v 1.7 2000/10/27 18:23:05 trow Exp $ */
+/* $Id: guppi-enums.h,v 1.8 2001/01/16 23:36:40 trow Exp $ */
 
 /*
  * guppi-enums.h
@@ -27,8 +27,8 @@
 #ifndef _INC_GUPPI_ENUMS_H
 #define _INC_GUPPI_ENUMS_H
 
-#include <gtk/gtk.h>
-
+/* #include <gtk/gtk.h> */
+#include <glib.h>
 #include <guppi-defs.h>
 
 BEGIN_GUPPI_DECLS 
@@ -79,4 +79,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_ENUMS_H */
 
-/* $Id: guppi-enums.h,v 1.7 2000/10/27 18:23:05 trow Exp $ */
+/* $Id: guppi-enums.h,v 1.8 2001/01/16 23:36:40 trow Exp $ */
