@@ -1,4 +1,4 @@
-/* $Id: guppi-gpl.h,v 1.4 2000/10/27 18:23:05 trow Exp $ */
+/* $Id: guppi-gpl.h,v 1.5 2001/01/16 23:36:40 trow Exp $ */
 
 /*
  * guppi-gpl.h
@@ -27,7 +27,7 @@
 #define _INC_GUPPI_GPL_H
 
 #include <stdio.h>
-#include <gtk/gtk.h>
+/* #include <gtk/gtk.h> */
 
 #include <guppi-defs.h>
 
@@ -39,4 +39,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_GPL_H */
 
-/* $Id: guppi-gpl.h,v 1.4 2000/10/27 18:23:05 trow Exp $ */
+/* $Id: guppi-gpl.h,v 1.5 2001/01/16 23:36:40 trow Exp $ */
