@@ -27,7 +27,7 @@
 
 
 #include <config.h>
-#include <gnome.h>
+/* #include <gnome.h> */
 #include <libguile/fluids.h>
 #ifdef USING_GUILE_GNOME_BINDINGS
 #include <guile-gtk.h>
