@@ -1,4 +1,4 @@
-/* $Id: guppi-paths.c,v 1.21 2000/12/16 03:42:50 trow Exp $ */
+/* $Id: guppi-paths.c,v 1.22 2001/01/16 23:36:40 trow Exp $ */
 
 /*
  * guppi-paths.c
@@ -25,7 +25,16 @@
  */
 
 #include <config.h>
-#include <gnome.h>
+/* #include <gnome.h> */
+#include <stdlib.h>
+
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-util.h>
+
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-config.h>
+#include <libgnome/gnome-i18n.h>
+
 #include <errno.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -430,4 +439,4 @@ guppi_paths_init (void)
 				    "Path cleanup");
 }
 
-/* $Id: guppi-paths.c,v 1.21 2000/12/16 03:42:50 trow Exp $ */
+/* $Id: guppi-paths.c,v 1.22 2001/01/16 23:36:40 trow Exp $ */
