@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-plug-in-spec.c,v 1.13 2000/12/17 05:24:58 trow Exp $ */
+/* $Id: guppi-plug-in-spec.c,v 1.14 2001/01/16 23:36:40 trow Exp $ */
 
 /*
  * guppi-plug-in-spec.c
@@ -29,6 +29,13 @@
 #include <stdio.h>
 #include <dirent.h>
 #include <ctype.h>
+#include <string.h>
+
+#include <glib.h>
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-util.h>
+#include <libgnome/gnome-i18n.h>
+
 #include <guppi-useful.h>
 #include "guppi-plug-in-spec.h"
 
@@ -933,4 +940,4 @@ guppi_plug_in_spec_shutdown (gpointer ignored)
 }
 
 
-/* $Id: guppi-plug-in-spec.c,v 1.13 2000/12/17 05:24:58 trow Exp $ */
+/* $Id: guppi-plug-in-spec.c,v 1.14 2001/01/16 23:36:40 trow Exp $ */
