@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-plug-in.c,v 1.20 2000/12/17 05:24:58 trow Exp $ */
+/* $Id: guppi-plug-in.c,v 1.21 2001/01/16 23:36:40 trow Exp $ */
 
 /*
  * guppi-plug-in.c
@@ -26,7 +26,7 @@
  */
 
 #include <config.h>
-#include <gnome.h>
+/* #include <gnome.h> */
 #include <errno.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -205,4 +205,4 @@ guppi_plug_in_code (GuppiPlugIn *pi)
   return GUPPI_PLUG_IN_SPEC (pi->spec)->code;
 }
 
-/* $Id: guppi-plug-in.c,v 1.20 2000/12/17 05:24:58 trow Exp $ */
+/* $Id: guppi-plug-in.c,v 1.21 2001/01/16 23:36:40 trow Exp $ */
