@@ -1,4 +1,4 @@
-/* $Id: guppi-python.c,v 1.14 2000/12/17 05:24:58 trow Exp $ */
+/* $Id: guppi-python.c,v 1.16 2001/01/20 18:59:21 trow Exp $ */
 
 /*
  * guppi-python.c
@@ -29,7 +29,10 @@
 #include <stdio.h>
 #include <string.h>
 #include <config.h>
-#include <gnome.h>
+/* #include <gnome.h> */
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-config.h>
+#include <libgnome/gnome-i18n.h>
 
 #define IN_GUPPI_PYTHON_C
 #include <Python.h>
@@ -44,30 +47,51 @@
 
 
 static void guppi_python_module_init (void);
+static PyObject *py_exec_module = NULL;
+static PyObject *py_globals = NULL;
 
 gint
 guppi_python_eval_str (const gchar * expression)
 {
   gchar *copy = guppi_strdup (expression);
-  gint val;
-  val = PyRun_SimpleString (copy);
+  PyObject *ret;
+
+  ret = PyRun_String (copy, Py_single_input, py_globals, py_globals);
   guppi_free (copy);
-  return val;
+  
+  if (ret == NULL)
+    return -1;
+
+  Py_DECREF (ret);
+  return 0;
 }
 
 gint
 guppi_python_eval_file (const gchar * filename)
 {
   gchar *copy;
-  gint val;
+  PyObject *ret, *module, *namespace;
   FILE *fp = fopen (filename, "r");
   if (fp == NULL)
     return 0;
   copy = guppi_strdup (filename);
-  val = PyRun_SimpleFile (fp, copy);
+
+  module = PyImport_AddModule ("__main__");
+  namespace = PyModule_GetDict (module);
+
+  ret = PyRun_File (fp, copy, Py_file_input, namespace, namespace);
+  
+  if (ret == NULL)
+    PyErr_Print ();
+
   guppi_free (copy);
   fclose (fp);
-  return val;
+  
+  if (ret == NULL)
+    return -1;
+  
+  Py_DECREF (ret);
+  return 0;
 }
 
 gboolean
@@ -105,6 +129,9 @@ guppi_python_init (void)
   Py_Initialize ();
 
   PySys_SetArgv (1, &prog_name);	/* so Python's sys.argv will exist */
+
+  py_exec_module = PyImport_AddModule ("__main__");
+  py_globals = PyModule_GetDict (py_exec_module);
   guppi_python_module_init ();
 }
 
@@ -380,7 +407,6 @@ static void
 PyGuppi_dealloc (PyGuppi_Object * self)
 {
   guppi_unref0 (self->obj);
-  gtk_object_unref (self->obj);
   PyMem_DEL (self);
 }
 
@@ -1008,6 +1034,7 @@ static
 guppi_python_module_init ()
 {
   PyObject *m, *d, *private;
+  PyObject *py_ret;
 
   _PyGuppi_API = &functions;
   m = Py_InitModule ("_guppi", _guppimoduleMethods);
@@ -1060,21 +1087,25 @@ guppi_python_module_init ()
     return;
   }
   d = PyModule_GetDict (m);
-  Py_DECREF (m);
+
   d = PyDict_GetItemString (d, "environ");
   d = PyMapping_GetItemString (d, "PYGUPPI_FATAL_EXCEPTIONS");
   if (d == NULL)
     PyErr_Clear ();
   else {
     functions.fatalExceptions = PyGuppi_FatalExceptions = PyObject_IsTrue (d);
-    Py_DECREF (d);
   }
 
   if (PyErr_Occurred ())
     Py_FatalError ("can't initialise module _guppi");
 
-  PyRun_SimpleString ("import sys\nsys.path.append(\"" \
-		      GUPPI_SCRIPTS "/python\")\n");
+  py_ret = PyRun_String ("import sys\nsys.path.append(\"" \
+			 GUPPI_SCRIPTS "/python\")\n",
+			 Py_single_input, py_globals, py_globals);
+  if (py_ret == NULL)
+    g_warning ("Error setting Python path\n");
+  else
+    Py_DECREF (py_ret);
 }
 
 /****************************************************************************/
@@ -1177,4 +1208,4 @@ py2fn_d__d_d (PyObject * proc)
   return guppi_fn_wrapper_new_d__d_d (py_eval_d__d_d, (gpointer) proc);
 }
 
-/* $Id: guppi-python.c,v 1.14 2000/12/17 05:24:58 trow Exp $ */
+/* $Id: guppi-python.c,v 1.16 2001/01/20 18:59:21 trow Exp $ */
