@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-stream-preview.c,v 1.9 2000/12/17 05:24:58 trow Exp $ */
+/* $Id: guppi-stream-preview.c,v 1.10 2001/01/16 23:36:40 trow Exp $ */
 
 /*
  * guppi-stream-preview.c
@@ -26,7 +26,19 @@
  */
 
 #include <config.h>
-#include <gnome.h>
+/* #include <gnome.h> */
+#include <glib.h>
+
+#include <gtk/gtkframe.h>
+#include <gtk/gtksignal.h>
+#include <gtk/gtkvbox.h>
+#include <gtk/gtkscrolledwindow.h>
+#include <gtk/gtklabel.h>
+
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-config.h>
+#include <libgnome/gnome-i18n.h>
+
 #include "guppi-convenient.h"
 #include "guppi-stream-preview.h"
 
@@ -868,4 +880,4 @@ guppi_stream_preview_glade_custom_func (gchar * name,
 
 
 
-/* $Id: guppi-stream-preview.c,v 1.9 2000/12/17 05:24:58 trow Exp $ */
+/* $Id: guppi-stream-preview.c,v 1.10 2001/01/16 23:36:40 trow Exp $ */
